package
Version:
v0.0.0-...-0adb5f9
Opens a new window with list of versions in this module.
Published: Nov 2, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CacheEntry struct {
Query string `json:"query"`
Results []Package `json:"results"`
Timestamp time.Time `json:"timestamp"`
}
type Package struct {
Name string `json:"name"`
ImportPath string `json:"import_path"`
Description string `json:"description"`
Version string `json:"version,omitempty"`
IsInstalled bool `json:"is_installed,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.